@@ -2,6 +2,13 @@ from functools import partial
 import math
 import contextlib
 
+#   _       _
+#  (_) ___ | |_  _ __
+#  | |/ __|| __|| '__|
+#  | |\__ \| |_ | |
+#  |_||___/ \__||_|    use strings as integers
+
+__version__ = "0.0.7"
 
 class istr(str):
     """
@@ -31,7 +38,8 @@ class istr(str):
         it is possible to give more than one parameter, in which case a tuple
         of the istrs of the parameters will be returned, which can be handy
         to multiple assign, e.g.
-            a, b, c = istr(5, 6, 7) ==> a=istr("5') , b=istr("6"), c=istr("7")"""
+            a, b, c = istr(5, 6, 7) ==> a=istr("5') , b=istr("6"), c=istr("7")
+"""
 
     _format = ""
 
@@ -382,9 +390,7 @@ class istr(str):
 
 
 def main():
-    zero=istr("0")
-    print(bool(zero))
-
+    ...
 
 if __name__ == "__main__":
     main()
